/*
  Simple MPI program that sends a single message from Process 0 to
  Process 1

  Jim Teresco
  Department of Computer Science
  Williams College

  Created: Fall 2000

  Last Modification:
  Wed Feb 26 16:58:29 EST 2003

  $Id$
*/

#include <stdio.h>
#include <mpi.h>

int main(int argc, char *argv[]) {
  int rc;
  MPI_Status status;
  int mypid, numprocs;
  int message;

  /* Initialize MPI */
  rc = MPI_Init(&argc, &argv);
  if (rc != MPI_SUCCESS) {
    fprintf(stderr,"Cannot initialize MPI\n");
    MPI_Abort(MPI_COMM_WORLD, 1);
  }

  /* query MPI for the number of processes */
  MPI_Comm_size(MPI_COMM_WORLD, &numprocs);
  if (numprocs != 2) {
    fprintf(stderr,"This program must run on 2 processes, found %d\n", 
	    numprocs);
    MPI_Abort(MPI_COMM_WORLD, 1);
  }

  /* query MPI for my rank */
  MPI_Comm_rank(MPI_COMM_WORLD, &mypid);

  /* proc 0 does a blocking send of a single int value */
  if (mypid == 0) {
    message = 17;
    printf("Proc 0 sending %d to proc 1\n",message);
    MPI_Send(&message, 1, MPI_INT, 1, 1, MPI_COMM_WORLD);
  }

  /* proc 1 does a blocking receive of a single int value */
  if (mypid == 1) {
    MPI_Recv(&message, 1, MPI_INT, 0, 1, MPI_COMM_WORLD, &status);
    printf("Proc 1 received %d from proc 0\n",message);
  }

  /* clean up after MPI */
  MPI_Finalize();
}

